import copy
import os
import unittest

from integration.partial.integration_test_utils import IntegrationTestUtils


class TestSurvey(unittest.TestCase):

    TEST_OUT_PATH: str = "not_set"
    TEST_START_DATE: str = '20221001'
    TEST_JOB_DIR: str = "SURVEYDATA_" + TEST_START_DATE

    @classmethod
    def setUpClass(cls) -> None:
        TestSurvey.write_temp_run_config_file()
        TestSurvey.unpack_dependencies()
        TestSurvey.run_survey_pipeline()


    @staticmethod
    def write_temp_run_config_file():
        nowstring: str = IntegrationTestUtils.get_now_string()
        prefix: str = "temp_survey_" + nowstring
        # prefix: str = ""

        default_config = IntegrationTestUtils.DEFAULT_CONFIG_FILE_PATH
        default_config_dict: dict = IntegrationTestUtils.load_json_file(default_config)
        run_dict: dict = copy.deepcopy(default_config_dict)
        TestSurvey.TEST_OUT_PATH = run_dict['WorkspacePathout'] + prefix + os.sep
        run_dict['WorkspacePathout'] = TestSurvey.TEST_OUT_PATH
        run_dict['WorkspacePath'] = TestSurvey.TEST_OUT_PATH
        run_dict['Survey']['SkipServerDownload'] = True
        run_dict['ServerName'] = ''  # nothing, as local machine

        IntegrationTestUtils.write_json_file(run_dict, IntegrationTestUtils.TEMP_CONFIG_FILE_PATH)

    @staticmethod
    def unpack_dependencies():
        IntegrationTestUtils.unpack_zip(IntegrationTestUtils.EXAMPLE_SURVEY_FILE_PATH, TestSurvey.TEST_OUT_PATH)

    @staticmethod
    def run_survey_pipeline():
        component = 'Survey'
        IntegrationTestUtils.run_unittest_pipeline(component, TestSurvey.TEST_START_DATE)


    def test_standard_run_input_status_success(self):
        status_file_path = os.path.join(TestSurvey.TEST_OUT_PATH, TestSurvey.TEST_JOB_DIR, "STATUS_SUCCESS")
        success_file_exists: bool = os.path.isfile(status_file_path)
        self.assertTrue(success_file_exists)

    def test_standard_run_input_merged_survey_created(self):
        status_file_path = os.path.join(TestSurvey.TEST_OUT_PATH, TestSurvey.TEST_JOB_DIR,
                                        "ExportCSV", "Merged_SurveyData.csv")
        success_file_exists: bool = os.path.isfile(status_file_path)
        file_not_empty: bool = IntegrationTestUtils.check_file_not_empty(status_file_path)
        self.assertTrue(success_file_exists)
        self.assertTrue(file_not_empty)


if __name__ == '__main__':
    unittest.main()
